@@ -71,16 +71,45 @@ class settings():
         if key in self._databox.hkeys: return self._databox.h(key)
         else:                          return None
 
+    def _set_theme_figures(self, theme):    
+        """
+        Sets the matplotlib figure theme.
+        
+        Parameters
+        ----------
+        theme : str
+            Can be 'classic' (for white) or 'dark_background' for dark theme
+            (or any other theme that exists).
+        """
+        _s.pylab.style.use(theme)
+
     def set(self, key, value=None):
         """
         Sets the key-value pair and dumps to the preferences file.
+        
+        If value=None, pops / removes the setting.
         """
-        if not value is None: self._databox.h(**{key:value})
-        else:                 self._databox.pop_header(key, ignore_error=True)
+        if not key is None:            
+            if not value is None: self._databox.h(**{key:value})
+            else:                 self._databox.pop_header(key, ignore_error=True)
 
+        # If figure theme is provided, update it.
+        if key == 'dark_theme_figures':
+            self._set_theme_figures('dark_background' if self['dark_theme_figures'] else 'classic')
+            
+            if not self['dark_theme_figures']: 
+                _s.pylab.rcParams['figure.facecolor'] = 'white'
+            
+        # Other pylab settings
+        if key in ['font_size']:
+             _s.pylab.rcParams.update({
+                 'font.size' : self['font_size']
+                 })
+        
         # Save the settings.
         self.save()
 
+
     def pop(self, *keys):
         """
         Pops the specified keys.
